@@ -65,11 +65,16 @@ EDIT_FILETYPES = (
                                 '.reg', '.cfg', '.desktop')),
                  )
 
+def _create_filter(title, ftypes):
+    return "%s (*%s)" % (title, " *".join(ftypes))
+
+ALL_FILTER = "%s (*)" % _("All files")
+
 def _get_filters(filetypes):
     filters = []
     for title, ftypes in filetypes:
-        filters.append("%s (*%s)" % (title, " *".join(ftypes)))
-    filters.append("%s (*)" % _("All files"))
+        filters.append(_create_filter(title, ftypes))
+    filters.append(ALL_FILTER)
     return ";;".join(filters)
 
 def _get_extensions(filetypes):
@@ -78,6 +83,16 @@ def _get_extensions(filetypes):
         ftype_list += list(ftypes)
     return ftype_list
 
+def get_filter(filetypes, ext):
+    """Return filter associated to file extension"""
+    if not ext:
+        return ALL_FILTER
+    for title, ftypes in filetypes:
+        if ext in ftypes:
+            return _create_filter(title, ftypes)
+    else:
+        return ''
+
 EDIT_FILTERS = _get_filters(EDIT_FILETYPES)
 EDIT_EXT = _get_extensions(EDIT_FILETYPES)+['']
 
@@ -95,7 +110,7 @@ INCLUDE_PATTERNS = [r'|'.join(['\\'+_ext+r'$' for _ext in EDIT_EXT if _ext])+\
                     r'|README|INSTALL',
                     r'\.pyw?$|\.ipy$|\.txt$|\.rst$',
                     '.']
-EXCLUDE_PATTERNS = [r'\.pyc$|\.pyo$|\.orig$|\.hg|\.svn|build',
+EXCLUDE_PATTERNS = [r'\.pyc$|\.pyo$|\.orig$|\.hg|\.svn|\bbuild\b',
                     r'\.pyc$|\.pyo$|\.orig$|\.hg|\.svn']
 
 # Name filters for file/project explorers (excluding files without extension)
