@@ -37,6 +37,15 @@ from spyderlib.widgets.findreplace import FindReplace
 from spyderlib.plugins import SpyderPluginWidget, PluginConfigPage
 
 
+def is_mpl_patch_available():
+    """Return True if Matplotlib patch is available"""
+    if programs.is_module_installed('matplotlib'):
+        from spyderlib import mpl_patch
+        return mpl_patch.is_available()
+    else:
+        return False
+
+
 class ExternalConsoleConfigPage(PluginConfigPage):
     def __init__(self, plugin, parent):
         PluginConfigPage.__init__(self, plugin, parent)
@@ -339,9 +348,9 @@ to use this feature wisely, e.g. for debugging purpose."""))
         ipython_group = QGroupBox(
                             _("IPython interpreter command line options"))
         ipython_layout = QVBoxLayout()
-        ipython_is_installed = programs.is_module_installed('IPython', '0.1')
+        ipython_is_installed = programs.is_module_installed('IPython', '>=0.10')
         if ipython_is_installed:
-            if programs.is_module_installed('IPython', '0.12'):
+            if programs.is_module_installed('IPython', '>=0.12'):
                 ipython_edit_012 = self.create_lineedit("IPython >=v0.12",
                              'ipython_kernel_options', alignment=Qt.Horizontal)
                 ipython_layout.addWidget(ipython_edit_012)
@@ -383,11 +392,9 @@ to use this feature wisely, e.g. for debugging purpose."""))
                      mpl_patch_label.setEnabled)
         
         mpl_installed = programs.is_module_installed('matplotlib')
-        if mpl_installed:
-            from spyderlib import mpl_patch
-            if not mpl_patch.is_available():
-                mpl_patch_box.hide()
-                mpl_patch_label.hide()
+        if not is_mpl_patch_available():
+            mpl_patch_box.hide()
+            mpl_patch_label.hide()
         
         mpl_layout = QVBoxLayout()
         mpl_layout.addLayout(mpl_backend_layout)
@@ -688,7 +695,8 @@ class ExternalConsole(SpyderPluginWidget):
             else:
                 pythonstartup = self.get_option('pythonstartup', None)
             monitor_enabled = self.get_option('monitor/enabled')
-            mpl_patch_enabled = self.get_option('matplotlib/patch')
+            mpl_patch_enabled = is_mpl_patch_available() and\
+                                self.get_option('matplotlib/patch')
             if self.get_option('matplotlib/backend/enabled'):
                 mpl_backend = self.get_option('matplotlib/backend/value')
             else:
@@ -1117,7 +1125,7 @@ class ExternalConsole(SpyderPluginWidget):
         
     def get_default_ipython_kernel_options(self):
         """Return default ipython kernel command line arguments"""
-        default_options = ["python"]
+        default_options = []
         if programs.is_module_installed('matplotlib'):
             default_options.append("--pylab=inline")
         return " ".join(default_options)
@@ -1135,7 +1143,7 @@ class ExternalConsole(SpyderPluginWidget):
         if wdir is None:
             wdir = os.getcwdu()
         args = self.get_option('ipython_kernel_options',
-                               "python --pylab=inline")
+                               "--pylab=inline")
         self.start(fname=None, wdir=unicode(wdir), args=args,
                    interact=True, debug=False, python=True,
                    ipython_kernel=True)
