@@ -24,18 +24,23 @@ import re
 # Keeping a reference to the original sys.exit before patching it
 ORIGINAL_SYS_EXIT = sys.exit
 
-try:
-    # Test if IPython v0.11+ is installed
-    import IPython
-    if IPython.__version__.startswith(('0.11', '0.12'))\
-       and os.environ.get('QT_API', 'pyqt') == 'pyqt':
+# Test if IPython v0.12+ is installed to eventually switch to PyQt API #2
+from spyderlib.utils.programs import is_module_installed
+if is_module_installed('IPython.frontend.qt', '>=0.12'):
+    # Importing IPython will eventually set the QT_API environment variable
+    import IPython  # analysis:ignore
+    if os.environ.get('QT_API', 'pyqt') == 'pyqt':
         # If PyQt is the selected GUI toolkit (at this stage, only the
-        # bootstrap script has eventually set this option),
-        # switch to PyQt API #2 by simply importing the IPython qt module
+        # bootstrap script has eventually set this option), switch to 
+        # PyQt API #2 by simply importing the IPython qt module
         os.environ['QT_API'] = 'pyqt'
-        from IPython.external import qt #analysis:ignore
-except ImportError:
-    pass
+        try:
+            from IPython.external import qt  #analysis:ignore
+        except ImportError:
+            # Avoid raising any error here: the spyderlib.requirements module
+            # will take care of it, in a user-friendly way (Tkinter message box
+            # if no GUI toolkit is installed)
+            pass
 
 # Check requirements
 from spyderlib import requirements
@@ -46,23 +51,8 @@ requirements.check_qt()
 set_attached_console_visible = None
 is_attached_console_visible = None
 if os.name == 'nt':
-    try:
-        import win32gui, win32console, win32con
-        win32console.GetConsoleWindow() # do nothing, this is just a test
-        def set_attached_console_visible(state):
-            """Show/hide console window attached to current window
-            
-            This is for Windows platforms only. Requires pywin32 library."""
-            win32gui.ShowWindow(win32console.GetConsoleWindow(),
-                                win32con.SW_SHOW if state else win32con.SW_HIDE)
-        def is_attached_console_visible():
-            """Return True if attached console window is visible"""
-            return win32gui.IsWindowVisible(win32console.GetConsoleWindow())
-    except (ImportError, NotImplementedError):
-        # This is not a Windows platform (ImportError)
-        # or pywin32 is not installed (ImportError)
-        # or GetConsoleWindow is not implemented on current platform
-        pass
+    from spyderlib.utils.windows import (set_attached_console_visible,
+                                         is_attached_console_visible)
 
 # Workaround: importing rope.base.project here, otherwise this module can't
 # be imported if Spyder was executed from another folder than spyderlib
@@ -226,7 +216,7 @@ class MainWindow(QMainWindow):
     spyder_path = get_conf_path('.path')
     BOOKMARKS = (
          ('PyQt4',
-          "http://www.riverbankcomputing.co.uk/static/Docs/PyQt4/pyqt4ref.html",
+          "http://www.riverbankcomputing.co.uk/static/Docs/PyQt4/html/index.html",
           _("PyQt4 Reference Guide"), "qt.png"),
          ('PyQt4',
           "http://www.riverbankcomputing.co.uk/static/Docs/PyQt4/html/classes.html",
@@ -546,7 +536,8 @@ class MainWindow(QMainWindow):
             # Tools menu
             self.tools_menu = self.menuBar().addMenu(_("&Tools"))
             
-            # View menu will be inserted afterwards
+            # View menu
+            self.view_menu = self.menuBar().addMenu(_("&View"))
             
             # Help menu
             self.help_menu = self.menuBar().addMenu("?")
@@ -785,6 +776,27 @@ class MainWindow(QMainWindow):
                                             'qtassistant.png', "assistant")
             if qta_act:
                 self.help_menu_actions.append(qta_act)
+            # Windows-only: documentation located in sys.prefix/Doc
+            def add_doc_action(text, path):
+                """Add doc action to help menu"""
+                ext = osp.splitext(path)[1]
+                if ext:
+                    icon = get_icon(ext[1:]+".png")
+                else:
+                    icon = get_std_icon("DirIcon")
+                path = file_uri(path)
+                action = create_action(self, text, icon=icon,
+                               triggered=lambda path=path: start_file(path))
+                self.help_menu_actions.append(action)
+            if os.name == 'nt':
+                sysdocpth = osp.join(sys.prefix, 'Doc')
+                for docfn in os.listdir(sysdocpth):
+                    pt = r'([a-zA-Z\_]*)(doc)?(-dev)?(-ref)?(-user)?.(chm|pdf)'
+                    match = re.match(pt, docfn)
+                    if match is not None:
+                        pname = match.groups()[0]
+                        if pname not in ('Python', ):
+                            add_doc_action(pname, osp.join(sysdocpth, docfn))
             # Documentation provided by Python(x,y), if available
             try:
                 from xy.config import DOC_PATH as xy_doc_path
@@ -792,16 +804,7 @@ class MainWindow(QMainWindow):
                 def add_xydoc(text, pathlist):
                     for path in pathlist:
                         if osp.exists(path):
-                            ext = osp.splitext(path)[1]
-                            if ext:
-                                icon = get_icon(ext[1:]+".png")
-                            else:
-                                icon = get_std_icon("DirIcon")
-                            path = file_uri(path)
-                            action = create_action(self, text, icon=icon,
-                                                   triggered=lambda path=path:
-                                                             start_file(path))
-                            self.help_menu_actions.append(action)
+                            add_doc_action(text, path)
                             break
                 self.help_menu_actions.append(None)
                 add_xydoc(_("Python(x,y) documentation folder"),
@@ -837,7 +840,7 @@ class MainWindow(QMainWindow):
             self.help_menu_actions.append(web_resources)
             
             # IPython frontend action
-            if is_module_installed('IPython', '0.12'):
+            if is_module_installed('IPython', '>=0.12'):
                 ipf_action = create_action(self, _("New IPython frontend..."),
                                            icon="ipython.png",
                                            triggered=self.new_ipython_frontend)
@@ -853,7 +856,6 @@ class MainWindow(QMainWindow):
                     print >>STDERR, "%s: %s" % (mod, str(error))
                                 
             # View menu
-            self.view_menu = self.menuBar().addMenu(_("&View"))
             self.windows_toolbars_menu = QMenu(_("Windows and toolbars"), self)
             self.connect(self.windows_toolbars_menu, SIGNAL("aboutToShow()"),
                          self.update_windows_toolbars_menu)
@@ -890,8 +892,6 @@ class MainWindow(QMainWindow):
                                          self.fullscreen_action, None,
                                          reset_layout_action, quick_layout_menu,
                                          None, self.close_dockwidget_action))
-            self.menuBar().insertMenu(self.help_menu.menuAction(),
-                                      self.view_menu)
             
             # Adding external tools action to "Tools" menu
             external_tools_act = create_action(self, _("External Tools"),
@@ -1410,23 +1410,22 @@ class MainWindow(QMainWindow):
             </li><li>Discussions around the project: 
             <a href="%s">Google Group</a>
             </li></ul>
-            <p>This project is part of 
-            <a href="http://www.pythonxy.com">Python(x,y) distribution</a>
-            <p>Python %s, Qt %s, %s %s on %s"""
+            <p>This project is part of a larger effort to promote and 
+            facilitate the use of Python for scientific and enginering 
+            software development. The popular Python distributions 
+            <a href="http://www.pythonxy.com">Python(x,y)</a> and 
+            <a href="http://code.google.com/p/winpython/">WinPython</a> 
+            also contribute to this plan.
+            <p>Python %s %dbits, Qt %s, %s %s on %s"""
             % ("Spyder", __version__, __project_url__,
-                 "<span style=\'color: #444444\'><b>",
-                 pyflakes_version,
-                 "</b></span>",
-                 "<span style=\'color: #444444\'><b>",
-                 rope_version,
-                 "</b></span>",
-                 "<span style=\'color: #444444\'><b>",
-                 "</b></span>",
-                 __project_url__, __forum_url__,
-                 platform.python_version(),
-                 spyderlib.qt.QtCore.__version__,
-                 qt_lib, spyderlib.qt.__version__,
-                 platform.system()) )
+               "<span style=\'color: #444444\'><b>", pyflakes_version,
+               "</b></span>", "<span style=\'color: #444444\'><b>",
+               rope_version, "</b></span>",
+               "<span style=\'color: #444444\'><b>", "</b></span>",
+               __project_url__, __forum_url__, platform.python_version(),
+               64 if sys.maxsize > 2**32 else 32,
+               spyderlib.qt.QtCore.__version__, qt_lib,
+               spyderlib.qt.__version__, platform.system()))
 
     def report_issue(self):
         qt_api = os.environ['QT_API']
