@@ -767,11 +767,15 @@ class TextEditBaseWidget(QPlainTextEdit):
             # and if not, moves the cursor one word to the left (otherwise,
             # if the character to the left do not match the "word regexp" 
             # (see below), the word to the left of the cursor won't be 
-            # selected)
-            cursor2 = self.textCursor()
-            cursor2.movePosition(QTextCursor.NextCharacter,
-                                 QTextCursor.KeepAnchor)
-            if not unicode(cursor2.selectedText()).strip():
+            # selected), but only if the first character to the left is not a
+            # white space too.
+            def is_space(move):
+                curs = self.textCursor()
+                curs.movePosition(move, QTextCursor.KeepAnchor)
+                return not unicode(curs.selectedText()).strip()
+            if is_space(QTextCursor.NextCharacter):
+                if is_space(QTextCursor.PreviousCharacter):
+                    return
                 cursor.movePosition(QTextCursor.WordLeft)
 
         cursor.select(QTextCursor.WordUnderCursor)
@@ -1120,25 +1124,32 @@ class TextEditBaseWidget(QPlainTextEdit):
     def stdkey_tab(self):
         self.insert_text(self.indent_chars)
 
-    def stdkey_home(self, shift, prompt_pos=None):
+    def stdkey_home(self, shift, ctrl, prompt_pos=None):
         """Smart HOME feature: cursor is first moved at 
         indentation position, then at the start of the line"""
-        if prompt_pos is None:
-            start_position = self.get_position('sol')
-        else:
-            start_position = self.get_position(prompt_pos)
-        text = self.get_text(start_position, 'eol')
-        indent_pos = start_position+len(text)-len(text.lstrip())
-        cursor = self.textCursor()
         move_mode = self.__get_move_mode(shift)
-        if cursor.position() != indent_pos:
-            cursor.setPosition(indent_pos, move_mode)
+        if ctrl:
+            self.moveCursor(QTextCursor.Start, move_mode)
         else:
-            cursor.setPosition(start_position, move_mode)
-        self.setTextCursor(cursor)
+            cursor = self.textCursor()
+            if prompt_pos is None:
+                start_position = self.get_position('sol')
+            else:
+                start_position = self.get_position(prompt_pos)
+            text = self.get_text(start_position, 'eol')
+            indent_pos = start_position+len(text)-len(text.lstrip())
+            if cursor.position() != indent_pos:
+                cursor.setPosition(indent_pos, move_mode)
+            else:
+                cursor.setPosition(start_position, move_mode)
+            self.setTextCursor(cursor)
 
-    def stdkey_end(self, shift):
-        self.moveCursor(QTextCursor.EndOfBlock, self.__get_move_mode(shift))
+    def stdkey_end(self, shift, ctrl):
+        move_mode = self.__get_move_mode(shift)
+        if ctrl:
+            self.moveCursor(QTextCursor.End, move_mode)
+        else:
+            self.moveCursor(QTextCursor.EndOfBlock, move_mode)
 
     def stdkey_pageup(self):
         pass
@@ -1161,6 +1172,16 @@ class TextEditBaseWidget(QPlainTextEdit):
         """Reimplemented to handle focus"""
         self.emit(SIGNAL("focus_changed()"))
         QPlainTextEdit.focusOutEvent(self, event)
+    
+    def wheelEvent(self, event):
+        """Reimplemented to emit zoom in/out signals when Ctrl is pressed"""
+        if event.modifiers() & Qt.ControlModifier:
+            if event.delta() < 0:
+                self.emit(SIGNAL("zoom_out()"))
+            elif event.delta() > 0:
+                self.emit(SIGNAL("zoom_in()"))
+            return
+        QPlainTextEdit.wheelEvent(self, event)
 
 
 class QtANSIEscapeCodeHandler(ANSIEscapeCodeHandler):
