@@ -135,7 +135,7 @@ class RopeProject(object):
             if DEBUG:
                 log_dt(LOG_FILENAME, "code_assist/sorted_proposals", t0)
             return [proposal.name for proposal in proposals]
-        except Exception, _error:
+        except Exception, _error:  #analysis:ignore
             if DEBUG:
                 log_last_error(LOG_FILENAME, "get_completion_list")
             return []
@@ -173,7 +173,7 @@ class RopeProject(object):
                 return [cts, doc_text]
             else:
                 return []
-        except Exception, _error:
+        except Exception, _error:  #analysis:ignore
             if DEBUG:
                 log_last_error(LOG_FILENAME, "get_calltip_text")
             return []
@@ -198,7 +198,7 @@ class RopeProject(object):
             if resource is not None:
                 filename = resource.real_path
             return filename, lineno
-        except Exception, _error:
+        except Exception, _error:  #analysis:ignore
             if DEBUG:
                 log_last_error(LOG_FILENAME, "get_definition_location")
             return (None, None)
@@ -997,7 +997,7 @@ class CodeEditor(TextEditBaseWidget):
             maxb /= 10
             digits += 1
         if self.linenumbers_margin:
-            linenumbers_margin = 3+self.fontMetrics().width('9')*digits
+            linenumbers_margin = 3+self.fontMetrics().width('9'*digits)
         else:
             linenumbers_margin = 0
         return linenumbers_margin+self.get_markers_margin()
@@ -1294,7 +1294,7 @@ class CodeEditor(TextEditBaseWidget):
         x = self.blockBoundingGeometry(self.firstVisibleBlock()) \
             .translated(offset.x(), offset.y()).left() \
             +self.get_linenumberarea_width() \
-            +self.fontMetrics().width('9')*self.edge_line.column+5
+            +self.fontMetrics().width('9'*self.edge_line.column)+5
         self.edge_line.setGeometry(\
                         QRect(x, cr.top(), 1, cr.bottom()))
         self.__set_scrollflagarea_geometry(cr)
@@ -1893,12 +1893,12 @@ class CodeEditor(TextEditBaseWidget):
         cursor.endEditBlock()
 
     def __is_comment_bar(self, cursor):
-        return cursor.block().text().startsWith('#' + '='*79)
+        return unicode(cursor.block().text()).startswith('#' + '='*79)
 
     def unblockcomment(self):
         """Un-block comment current line or selection"""
         def __is_comment_bar(cursor):
-            return cursor.block().text().startsWith('#' + '='*79)
+            return unicode(cursor.block().text()).startswith('#' + '='*79)
         # Finding first comment bar
         cursor1 = self.textCursor()
         if __is_comment_bar(cursor1):
@@ -1910,7 +1910,7 @@ class CodeEditor(TextEditBaseWidget):
         if not __is_comment_bar(cursor1):
             return
         def __in_block_comment(cursor):
-            return cursor.block().text().startsWith('#')
+            return unicode(cursor.block().text()).startswith('#')
         # Finding second comment bar
         cursor2 = QTextCursor(cursor1)
         cursor2.movePosition(QTextCursor.NextBlock)
@@ -2045,8 +2045,12 @@ class CodeEditor(TextEditBaseWidget):
                 last_obj = getobj(self.get_text('sol', 'cursor'))
                 if last_obj and not last_obj.isdigit():
                     self.emit(SIGNAL('trigger_code_completion(bool)'), True)
-        elif key == Qt.Key_Home and not ctrl:
-            self.stdkey_home(shift)
+        elif key == Qt.Key_Home:
+            self.stdkey_home(shift, ctrl)
+        elif key == Qt.Key_End:
+            # See Issue 495: on MacOS X, it is necessary to redefine this 
+            # basic action which should have been implemented natively
+            self.stdkey_end(shift, ctrl)
         elif text == '(' and not self.has_selected_text():
             self.hide_completion_widget()
             position = self.get_position('cursor')
